@@ -11,6 +11,11 @@ from vipy.util import tofilename, remkdir, filepath, filebase, isurl, try_import
 import glob
 from subprocess import DEVNULL, STDOUT
 import subprocess
+import shutil
+
+
+youtube_dl_exe = shutil.which('youtube-dl')        
+has_youtube_dl = youtube_dl_exe is not None and os.path.exists(youtube_dl_exe)
 
 
 def isactiveyoutuber(username):
@@ -56,10 +61,9 @@ def youtubeuser(tag, n_pages=1):
 
 def is_downloadable_url(path):
     """Check to see if youtube-dl can download the path, this requires exeecuting 'youtube-dl $URL -q -j' to see if the returncode is non-zero"""
-    ydl_exe = os.path.join(filepath(sys.executable), 'youtube-dl')
-    if not os.path.exists(ydl_exe):
-        raise ImportError('Optional package "youtube-dl" not installed -  Run "pip install youtube-dl"')
-    retcode = subprocess.call([ydl_exe, path, '-q', '-j'], stdout=DEVNULL, stderr=STDOUT) if isurl(path) else -1
+    if not has_youtube_dl:
+        raise ImportError('Optional package "youtube-dl" not installed -  Run "pip install youtube-dl"')    
+    retcode = subprocess.call([youtube_dl_exe, '-q', '-j'], stdout=DEVNULL, stderr=STDOUT) if isurl(path) else -1
     return isurl(path) and retcode == 0
 
 
@@ -131,14 +135,13 @@ def download(vidurl, vidfile, skip=False, writeurlfile=True, max_filesize='350m'
     """Use youtube-dl to download a video URL to a video file"""
 
     user_agent = random.choice(complete_user_agents)    
-    ydl_exe = os.path.join(filepath(sys.executable), 'youtube-dl')
-    if not os.path.exists(ydl_exe):
+    if not has_youtube_dl:
         raise ImportError('Optional package "youtube-dl" not installed -  Run "pip install youtube-dl"')
     try:
         print('[vipy.videosearch.download]: saving "%s" to "%s"' % (vidurl, vidfile))
         for f in glob.glob("%s*" % vidfile):
             os.remove(f)  # youtube-dl will not overwrite, so we force it
-        cmd = '%s %s "%s" -o %s --max-filesize %s --no-check-certificate --user-agent="%s"' % (ydl_exe, '-q' if not verbose else '', vidurl, vidfile, max_filesize, user_agent)  # must be on path            
+        cmd = '%s %s "%s" -o "%s" --no-check-certificate --max-filesize="%s" --user-agent="%s"' % (youtube_dl_exe, '-q' if not verbose else '', vidurl, vidfile, max_filesize, user_agent)  # must be on path            
         if verbose:
             print('[vipy.videosearch.download]: executing \'%s\'' % cmd)
         erno = os.system(cmd)
